stylist.engine — Stylist 0.3.dev1 documentation

# stylist.engine

Core of the style checking tool.

Classes

`CheckEngine`(styles) | Manages the checking of source files against style lists.

class stylist.engine.CheckEngine(styles)

  Bases: `object`

  Manages the checking of source files against style lists.

  Parameters

    styles (`Sequence`[`Style`]) – Styles to use when checking source.

  check(source_filename)

    Passes the eyes of all registered style lists over the source file.

    Parameters

      source_filename (`str`) – Path to source file.

    Return type

      `Sequence`[`Issue`]